@@ -11,12 +11,9 @@ class LfTest:
     USER_ID = '<USER-ID>'
     ARTICLE_ID = '<ARTICLE-ID>'
     
-    def __init__(self):
-        self.set_prop_values(LfEnvironments.PROD)
-
     def set_prop_values(self, env):
         config = ConfigParser.RawConfigParser()
-        config.read('test.properties')
+        config.read('test.ini')
         
         self.NETWORK_NAME = config.get(env.value, 'NETWORK_NAME')
         self.NETWORK_KEY = config.get(env.value, 'NETWORK_KEY')
