@@ -2,7 +2,7 @@ import datetime, unittest
 
 import jwt
 from livefyre import Livefyre
-from livefyre.tests import LfTest
+from livefyre.tests import LfTest, LfEnvironments
 
 
 class LivefyreTestCase(unittest.TestCase):
@@ -10,6 +10,7 @@ class LivefyreTestCase(unittest.TestCase):
     
     def setUp(self):
         self.test = LfTest()
+        self.test.set_prop_values(LfEnvironments.PROD)
     
 #     def test_basic_site_api(self):
 #         site = Livefyre.get_network(self.test.NETWORK_NAME, self.test.NETWORK_KEY).get_site(self.test.SITE_ID, self.test.SITE_KEY)
